==> attal_0.8.orig.tar.gz: attal-0.8/i18n/de/attal_ai_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>AiInterface</name>
    <message>
        <source>Attal: IA client</source>
        <translation>Attal: KI Client</translation>
    </message>
    <message>
        <source>Log level : Verbose</source>
        <translation>Log-Stufe: Viele Meldungen</translation>
    </message>
    <message>
        <source>Verbose</source>
        <translation>Viele Meldungen</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritische Meldungen</translation>
    </message>
    <message>
        <source>Quiet</source>
        <translation>Wenige Meldungen</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="obsolete">Verbindung aufbauen</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Verbindung trennen</translation>
    </message>
    <message>
        <source>Log Level</source>
        <translation>Log-Stufe</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <source>Can&apos;t connect</source>
        <translation>Die Verbindung kann nicht hergestellt werden</translation>
    </message>
    <message>
        <source>You&apos;re already connected to a server. Please disconnect first.</source>
        <translation>Sie sind bereits mit dem Server verbunden, bitte trennen Sie die Verbindung zuvor. </translation>
    </message>
    <message>
        <source>Log level : Normal</source>
        <translation>Log-Stufe: Normal</translation>
    </message>
    <message>
        <source>Log level : Critical</source>
        <translation>Log-Stufe: Kritische Meldungen</translation>
    </message>
    <message>
        <source>Log level : Quiet</source>
        <translation>Log-Stufe: Wenige Meldungen</translation>
    </message>
    <message>
        <source>Connect to server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Connect to server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Disconnect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigConnection</name>
    <message>
        <source>Connection to server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="unfinished">Verbindung aufbauen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> attal_0.9.2.orig.tar.gz: attal-0.9.2/i18n/de/attal_ai_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>AiInterface</name>
    <message>
        <source>Attal: IA client</source>
        <translation>Attal: KI Client</translation>
    </message>
    <message>
        <source>Log level : Verbose</source>
        <translation>Log-Stufe: Viele Meldungen</translation>
    </message>
    <message>
        <source>Verbose</source>
        <translation>Viele Meldungen</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritische Meldungen</translation>
    </message>
    <message>
        <source>Quiet</source>
        <translation>Wenige Meldungen</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="obsolete">Verbindung aufbauen</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Verbindung trennen</translation>
    </message>
    <message>
        <source>Log Level</source>
        <translation>Log-Stufe</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <source>Can&apos;t connect</source>
        <translation>Die Verbindung kann nicht hergestellt werden</translation>
    </message>
    <message>
        <source>You&apos;re already connected to a server. Please disconnect first.</source>
        <translation>Sie sind bereits mit dem Server verbunden, bitte trennen Sie die Verbindung zuvor. </translation>
    </message>
    <message>
        <source>Log level : Normal</source>
        <translation>Log-Stufe: Normal</translation>
    </message>
    <message>
        <source>Log level : Critical</source>
        <translation>Log-Stufe: Kritische Meldungen</translation>
    </message>
    <message>
        <source>Log level : Quiet</source>
        <translation>Log-Stufe: Wenige Meldungen</translation>
    </message>
    <message>
        <source>Connect to server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Connect to server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Disconnect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t load theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> has not been loaded successfully</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigConnection</name>
    <message>
        <source>Connection to server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="unfinished">Verbindung aufbauen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
